function output=foucault_pendulum(t, omega_times_sin_lambda, g_over_L, x0, xdot0, y0, ydot0)
% Animation of the Foucault pendulum analyzed in Chapter 8
% Example of usage (using the initial conditions  x(0)=0.01; x_dot(0) =0; y(0)=0; y_dot(0)=0 ):
% my_output = foucault_pendulum([0:0.001:30], 0.0727, 0.981, 0.01, 0,  0, 0);

disp(' ')
disp('  NOTE: THE FUNCTION foucault_pendulum RETURNS 5 COLUMNS CONTAINING ')
disp('  t, x, dx/dt, y, and dy/dt:')
disp(' ')

initial_conditions=[x0; xdot0; y0; ydot0];
[t, y]=ode45(@rhs_of_diff_eqs, t, initial_conditions, [], omega_times_sin_lambda, g_over_L);  

close all
figure('color', 'white');  plot(y(:,1), y(:,3));   grid        % plot of y versus x
xlabel('x', 'fontsize', 12), ylabel('y', 'fontsize', 12), title('Foucault pendulum path','fontsize', 12)

output=[t, y];   
% output is a n by 5 matrix, where n is the number of points in the time array t;
% column 1: t, column 2: x, column 3: dx/dt; column 4: y; column 5: dy/dt

x_coordinates=y(:,1);  y_coordinates=y(:,3);   
animate_nbars(x_coordinates, y_coordinates);         % ANIMATION:               

function dy_dt=rhs_of_diff_eqs(t, y,  omega_times_sin_lambda, g_over_L) 
    % Note:  y(1)=x, y(2)=d(x)/dt, y(3)=y, y(4)=d(y)/dt
  dy_dt(1)=y(2);   
  dy_dt(2)=2*omega_times_sin_lambda*y(4)-g_over_L*y(1);    % this is d2(x)/dt2
  dy_dt(3)=y(4);  
  dy_dt(4)=-2*omega_times_sin_lambda*y(2)-g_over_L*y(3);   % this is d2(y)/dt2
  dy_dt=[dy_dt(1); dy_dt(2); dy_dt(3); dy_dt(4)];

 % end of the file foucault.m