function  output=fourbar_mech_dynamics(t, L1, L2, L3, L4,  m2, m3, m4,  theta2_0, dtheta2_dt_0,  solution_number)
% Simulation for Example 7.9.3 in Section 7.9 of Chapter 7
% Example of usage [copy the line below, without the %, to the Matlab command window]: 
% my_output=fourbar_mech_dynamics([0:0.001:5], 1, 0.4, 0.8, 0.7, 3.75, 3, 3, pi/6, 0, 1); 
% 
% NOTE: for these values of L1, L3, and L4, the mechanism locks shortly after t=1.2 if 
% L2 > approximately 0.5.  If the mechanism locks, a standard error message will appear 
% on the computer screen, and the computation ends. If this occurs, ignore the message 
% but redesign the mechanism by changing the length of at least one of its bars to 
% prevent it from locking. 
%
% IN ADDITION TO ANIMATING THE MECHANISM, SUCH A CALL TO THE FUNCTION fourbar_mech_dynamics.m 
% GENERATES A len (WHICH IS THE NUMBER OF POINTS IN THE SPECIFIED ARRAY t) BY 10 MATRIX CALLED 
% output (OR ANY OTHER NAME YOU WANT TO USE BEFORE THE EQUAL SIGN SEEN IN LINE 1), WHOSE COLUMNS  
% ARE  t, theta2, theta3, theta4, d(theta2)/dt, d(theta3)/dt, d(theta4)/dt, d2(theta2)/dt2, 
%          d2(theta3)/dt2, d2(theta4)/dt2
%
%  my_output(:,4), my_output(:,2)*180/pi, FOR EXAMPLE, GIVE theta4 (IN RAD) AND theta2 (IN DEGREES).
%  TO PLOT theta4 IN DEGREES VERSUS TIME t, FOR EXAMPLE, TYPE, IN THE MATLAB COMMAND WINDOW,  
%  THE COMMANDS  figure(); plot(my_output(:,1), my_output(:,4)*180/(2*pi) )
%   To put a grid on the plot, if desired, type the command   grid
% 
% In this problem theta2 and d(theta2)/dt are not given; only their initial conditions theta2_0  
% and dtheta2_dt_0. The system is driven by a motor with a torque M_motor that is a specified    
% function of time in the function M_motor(t), which can be changed by the user.  
% 
% The variables theta2 and d(theta2)/dt are determined by integrating a second-order differential  
% equation obtained from the first row of the solution of Eq. (7.9.3n). The integration is done by a 
% call to the Matlab function ode45 [which calls the function rhs_diff_eqs(t, y) that specifies 
% the right hand side of the equations   dtheta2/dt= --- , and d(dtheta2/dt)/d t= ---]. 

if solution_number ~=1 & solution_number ~= 2, 
    disp(' -----> SOLUTION_NUMBER HAS TO BE  1 or 2 <----- '), output=[]; return, 
end

disp(' '),    disp('The function fourbar_mech_dynamics called fourbar_mechanism.') 
 
global d2theta2_dt2  
  % Since this is needed in the function rhs_diff_eqs, Matlab requires it to be  
  % declared global here and in that function. Otherwise the variable d2theta2_dt2  
  % would not be known by the function rhs_diff_eqs. This is not the case with Scilab.

  % Integration of the second-order diff. eq. for theta2. An arbitrary value is used for 
  % d2theta2_dt2 because one is needed in a call to fourbar_mechanism 
 d2theta2_dt2=0;  % this is an arbitrary value
 options=odeset('RelTol', 1.e-6, 'AbsTol', 1.e-6); % NOTE: with options=[] the solution is not accurate
 [t, y] = ode45(@rhs_diff_eqs, t, [theta2_0; dtheta2_dt_0], options, L1, L2, L3, L4, m2, m3, m4, solution_number); 
 theta2=y(:,1)';   dtheta2_dt=y(:,2)';  t=t'; 
  % NOTE: transposed the variables in [t, y] to obtain rows because rows, instead of columns, are
  % needed for these quantities in the call to the function fourbar_mechanism a few lines later.
  % Now, determine the row of valid values for d2theta2/dt2. After that is done,  
 %  call fourbar_mechanism to complete the solution and animate the motion
  len=length(theta2); temp=[]; 
  for k=1:len, 
   temp_prev= ang_acceleration(t(k), L1, L2, L3, L4,  m2, m3, m4, theta2(k), dtheta2_dt(k), solution_number); 
   temp=[temp, temp_prev]; % this is a 1 by len row 
  end 
  d2theta2_dt2=temp; 
   output = fourbar_mechanism(t, L1, L2, L3, L4, theta2, dtheta2_dt, d2theta2_dt2, solution_number);
  
 % disp(' ')
 % disp('MESSAGE FROM THE FUNCTION fourbar_mech_dynamics.m:') 
 % disp('THE 10 COLUMN MATRIX GENERATED BY THE FUNCTION fourbar_mech_dynamics.m')
 % disp('CONTAINS:  t, theta2, theta3, theta4, dtheta2_dt, dtheta3_dt, ')
 % disp('   dtheta4_dt,  d2theta2_dt2, d2theta3_dt2, d2theta4_dt2 ') 
 
% The following are the three functions needed for the calculations involved with this problem

function M_motor_of_t= M_motor(t),  M_motor_of_t=pi/6+1.5*pi*sin(2*t);   
% NOTE: change, if desired, the pi/6+1.5*pi*sin(2*t) to any other expression

function dy_dt = rhs_diff_eqs(t, y, L1, L2, L3, L4, m2, m3, m4, solution_number) 
 % state variables: y(1)=theta2,  y(2)=dtheta2_dt
 theta2=y(1);  dtheta2_dt=y(2);
 d2theta2_dt2 = ang_acceleration(t, L1, L2, L3, L4,  m2, m3, m4, theta2, dtheta2_dt, solution_number);
 dy_dt=[y(2); d2theta2_dt2]; 

 
function d2theta2_dt2 = ang_acceleration(t, L1, L2, L3, L4,  m2, m3, m4, theta2, dtheta2_dt, solution_number)
 global d2theta2_dt2   % In Matlab, this declaration is needed for passing d2theta2_dt2 from the main program to here
 fourbar = fourbar_kinematics(t, L1, L2, L3, L4, theta2, dtheta2_dt, d2theta2_dt2, solution_number); 
   % Here we have valid values for theta2, theta3, theta4, d(theta2)/dt, d(theta3)/dt, d(theta4)/dt 
   % Ignore d2theta3_dt2 and d2theta4_dt2 obtained by fourbar_kinematics
 %
 theta2=fourbar(:,2);  theta3=fourbar(:,3);  theta4=fourbar(:,4);   
 sin_theta2=sin(theta2);  sin_theta3=sin(theta3);  sin_theta4=sin(theta4);
 cos_theta2=cos(theta2);  cos_theta3=cos(theta3);  cos_theta4=cos(theta4);
 sin43=sin(theta4-theta3);  cos43=cos(theta4-theta3);      
 dtheta2_dt=fourbar(:,5); dtheta3_dt=fourbar(:,6); dtheta4_dt=fourbar(:,7); 
 dtheta2_dt_sq=dtheta2_dt^2; dtheta3_dt_sq=dtheta3_dt^2; dtheta4_dt_sq=dtheta4_dt^2; 
 %
% angular acceleration d2theta2_dt2=d2(theta2)/dt2 from Eq. (7.9.3n)
 M=[m2*L2^2/3,       0,                   0,                 L2*sin_theta2,  -L2*cos_theta2;
    0,               m3*L3^2/3,          -m3*L3*L4*cos43/2,  L3*sin_theta3,  -L3*cos_theta3;
    0,              -m3*L3*L4*cos43/2,   (m4/3+m3)*L4^2,    -L4*sin_theta4,   L4*cos_theta4;
    L2*sin_theta2,   L3*sin_theta3,      -L4*sin_theta4,     0,               0;
    L2*cos_theta2,   L3*cos_theta3,      -L4*cos_theta4,     0,               0]; 
 Minv=inv(M);     % M is the matrix seen in Eq. (7.9.3n)), and Minv is its inverse
%
 v1= M_motor(t);   v2=-m3*L3*L4*dtheta4_dt_sq*sin43/2;  v3=m3*L3*L4*dtheta3_dt_sq*sin43/2;  
 v4=  L4*dtheta4_dt_sq*cos_theta4 -L3*dtheta3_dt_sq*cos_theta3 -L2*dtheta2_dt_sq*cos_theta2;
 v5= -L4*dtheta4_dt_sq*sin_theta4 +L3*dtheta3_dt_sq*sin_theta3 +L2*dtheta2_dt_sq*sin_theta2;   
 d2theta2_dt2=Minv(1,1)*v1 +Minv(1,2)*v2 +Minv(1,3)*v3 +Minv(1,4)*v4 +Minv(1,5)*v5;

 % end of the file fourbar_mech_dynamics.m


