function  output=geneva_wheel(t, L, r1, theta1, dtheta1_dt, d2theta1_dt2)
% % Animation of the geneva wheel mechanism (if a bar is always engaged) in Section 3.3
% To slow down the animation, choose a smaller time step for the input array t  
% Conversely, to speed up the animation, choose a larger time step 
% For example, the array t=[0:0.001:5] yields a slower animation than the array t=[0:0.01:5] 
%
% Example of usage [copy the next two lines, without the %, to the Matlab command window]:
% t=[0:0.001:5]; theta1=pi/2+3*pi*sin(t); dtheta1_dt=3*pi*cos(t); d2theta1_dt2=-3*pi*sin(t); 
% my_output=geneva_wheel(t, 1, 0.3, theta1, dtheta1_dt, d2theta1_dt2);
%
% IN ADDITION TO ANIMATING THE MECHANISM, SUCH A CALL TO THE FUNCTION geneva_wheel.m
% GENERATES A len (WHERE len IS THE NUMBER OF POINTS IN THE ARRAY t) BY 8 MATRIX CALLED my_output, 
% WHOSE COLUMNS ARE   t, theta1, theta2, r2, dr2_dt, dtheta2_dt, d2r2_dt2, d2theta2_dt2
%  my_output(:,2), my_output(:,3)*180/pi, FOR EXAMPLE, GIVE theta1 (IN RADIANS) AND theta2 
% (IN DEGREES). TO PLOT theta2 VERSUS TIME t, FOR EXAMPLE, TYPE, IN THE MATLAB COMMAND WINDOW,  
% THE COMMANDS     figure( );   plot( my_output(:,1), my_output(:,3)*180/(2*pi) )
% To put a grid on the plot, type   grid

disp('  ')
disp('NOTE: IN ADDITION TO ANIMATING THE MECHANISM, THE FUNCTION ')
disp('geneva_wheel  RETURNS 8 COLUMNS CONTAINING ')
disp(' t, theta1, theta2, r2, d(r2)/dt, d(theta2)/dt, d2(r2)/dt2, d2(theta2)/dt2')

len_barPC=L+r1;  cos_theta1=cos(theta1); sin_theta1=sin(theta1); 
r2=sqrt( L^2+r1^2-2*L*r1*cos_theta1 );      % r2 from Eq. (3.3.3)
sin_theta2=r1*sin_theta1./r2;  cos_theta2=(L-r1.*cos_theta1)./r2;   % From Eqs. (3.3.2) and (3.3.1)
theta2=atan2(sin_theta2, cos_theta2);

% Now generate the cordinate matrices needed for the function animate_nbars:
len=length(t); 
xA=zeros(len,1); yA=xA;      xB=r1*cos_theta1';  yB=r1*sin_theta1';   % bar AB
xP=L-len_barPC*cos_theta2';  yP=len_barPC*sin_theta2';   xC=L*ones(len,1);   yC=xA;   % bar PC
x_coordinates=[xA, xB, xP, xC];  y_coordinates=[yA, yB, yP, yC];

% Delete existing figure windows, and call the function animate_nbars:
close all;  animate_nbars(x_coordinates, y_coordinates)

% Velocities and accelerations:
temp=r1*dtheta1_dt;    theta2=atan2(sin_theta2, cos_theta2); 
sin_theta1plustheta2 = sin(theta1+theta2);    cos_theta1plustheta2 = cos(theta1+theta2); 
dr2_dt = temp.*sin_theta1plustheta2;  dtheta2_dt = temp.*cos_theta1plustheta2./r2;
d2r2_dt2 = r1*d2theta1_dt2.*sin_theta1plustheta2 + r2.*(dtheta2_dt.^2) + r1*(dtheta1_dt.^2).*cos_theta1plustheta2;  
d2theta2_dt2 = ( r1*d2theta1_dt2.*cos_theta1plustheta2 - 2*dr2_dt.*dtheta2_dt - r1*(dtheta1_dt.^2).*sin_theta1plustheta2 )./r2;

output=[t; theta1; theta2; r2; dr2_dt; dtheta2_dt; d2r2_dt2; d2theta2_dt2]';

% end of the file geneva_wheel.m