function output=inclined_plane(t, m1_over_m2, k_over_m2, c2_over_m2, c1_over_m2, alpha, g, Lu, x0, xdot0, r0, rdot0)  
% Animation for Example 2.5.9. The animation draws five bars, AB, BC, AC, CD, and DE, 
%  each one with a small dot at their ends. 
% Example of usage ( using the initial conditions  x(0)=1; xdot(0)=0; r(0)=2; rdot(0)=0 )
% my_output = inclined_plane([0:0.005:20], 0.1,  5, 0, 0, pi/4, 9.81, 1, 1, 0,  2, 0);

initial_conditions=[x0; xdot0; r0; rdot0];
[t, y]=ode45(@rhs_of_diff_eqs, t, initial_conditions,[], m1_over_m2, k_over_m2, c2_over_m2, c1_over_m2, alpha, g, Lu);   
% This is a 5 by len matrix, where len is the number of points in the time array t
% 1st column: t,  2nd column: x, 3rd column: dx/dt;  4th column: r; 5th column: dr/dt
output= [t, y];  
   
% ANIMATION: 
   len=length(t);   col_of_ones=ones(len,1);      
   x=output(:,2); r=output(:,4);    
   xA=x;   xB=x+3;   xC=x;   xD=x+0.05*sin(alpha);   xE=xD+r*cos(alpha);
   yA=zeros(len,1);  yB=yA;  yC=3*tan(alpha)*col_of_ones; 
   yD=(3*tan(alpha)+0.05*cos(alpha))*col_of_ones;  yE=yD-r*sin(alpha); 
   x_coordinates=[xC, xA, xB, xC, xD, xE];   y_coordinates=[yC, yA, yB, yC, yD, yE]; 
   animate_nbars(x_coordinates, y_coordinates); 

function dy_dt=rhs_of_diff_eqs(t, y, m1_over_m2, k_over_m2, c2_over_m2, c1_over_m2, alpha, g, Lu) 
 % Note:  y(1)=x, y(2)=dx/dt, y(3)=r, y(4)=dr/dt 
 sin_alpha=sin(alpha);   cos_alpha=cos(alpha);   temp=m1_over_m2+sin_alpha^2; 
 dy_dt(1)=y(2);   
 dy_dt(2)=  ( (c2_over_m2*y(4)+k_over_m2*(y(3)-Lu))*cos_alpha-g*sin(alpha)*cos(alpha) -c1_over_m2*y(2) )/temp;    % this is d2(x)/dt2 from Eq. (2.5.9i)
 dy_dt(3)=y(4);  
 dy_dt(4)=( c1_over_m2*cos_alpha*y(2)+(1+m1_over_m2)*( g*sin_alpha-(c2_over_m2*y(4) +k_over_m2*(y(3)-Lu)) ) );    % d2(r)/dt2 from Eq. (2.5.9j)
 dy_dt=[dy_dt(1); dy_dt(2); dy_dt(3); dy_dt(4)];

% end of the file inclined_plane.m