function output=parabola_track(t, a, k_over_m, c_over_m, Lu, h, g, x0, xdot0)
% Example 2.8.9 
% Example of usage (with the initial conditions   x_0=-1,5; xdot_0=3*sqrt(2))):
% my_output = parabola_track([0:0.001:3], 1/3, 9/0.02, 1.4, 1.2, 1.2, 9.81, -1.5, 3*sqrt(2));
% NOTE:
% my_output is a n by 3 matrix, where n is the number of points in the time array t
%  1st column: t;  2nd column: x;   3rd column: dx/dt;  

initial_conditions=[x0; xdot0];
[t, y]=ode45(@rhs_of_diff_eqs, t, initial_conditions, [],  a, k_over_m, c_over_m, Lu, h, g); 
output=[t, y];     x=y(:,1);  y=a*x.^2;

close all
% Create a figure window and plot x(t) versus time t
figure('color', 'white');  plot(t, x),   grid     
xlabel('t  (seconds)', 'fontsize', 12), ylabel('x(t)  (meters)', 'fontsize', 12) 
title('Example 2.8.9','fontsize', 12)

animate_nbars(x, y)  % ANIMATION of the ball moving on the parabolic track y=a*x^2

function dy_dt=rhs_of_diff_eqs(t, y,  a, k_over_m, c_over_m, Lu, h, g) 
  % Note:  y(1)=x, y(2)=dx/dt
  x_squared=y(1)^2;
  dy_dt(1)=y(2);     % the next expression is d2x_dt2 from Eq. (2.8.9c) 
  dy_dt(2)=(k_over_m*(1-Lu/sqrt(y(1)^2+(a*y(1)^2-h)^2))*(2*a*(h-a*y(1)^2)-1)*y(1)-2*a*g*y(1)-4*a^2*y(1)*y(2)^2)/(1+4*(a^2)*y(1)^2)-c_over_m*y(2);
  dy_dt=[dy_dt(1); dy_dt(2)];

% end of the file parabola_track.m