function output = sim_model_ex5_3_13(t, k_factor, c1_star, c2_star, phi_0, phidot_0, theta_0, thetadot_0)
% Example 5.3.13 (t here is actually the normalized time tau)
% Example of usage [using the initial conditions phi_0=20*pi/180; 
%                      phidot_0=0; theta_0=32*pi/180; thetadot_0=50]:
% my_output = sim_model_ex5_3_13([0:0.002:50], 12, 0.1, 0.1, 20*pi/180, 0, 32*pi/180, 50);

disp(' ')
disp('The k_factor is 12*(1+m1/(3*m2)/[(b/L)^2+(h/L)^2)]')
disp('Change it, if desired, to any other appropriate value')
disp('NOTE: IN ADDITION TO ANIMATING THE SYSTEM ANALYZED IN EXAMPLE 5.3.13,')
disp('AND PLOTTING phi AND theta versus time, A CALL TO THE FUNCTION sim_model_ex5_3_13,')  
disp(' AS EXEMPLIFIED IN THE FIRST 4 COMMENT LINES OF THIS FUNCTION,') 
disp(' RETURNS 5 COLUMNS CONTAINING  t, phi, d(phi)/dtau, theta, and d(theta)/dtau')
disp(' PLOTS CAN THE BE DONE USING THE plot COMMAND')

initial_conditions=[phi_0; phidot_0; theta_0; thetadot_0];
[t, y]=ode45(@rhs_of_diff_eqs, t, initial_conditions,  [],  k_factor, c1_star, c2_star);
output=[t, y];  
 % The variable output is a n by 5 matrix, where n is the number of points in the array t
 % column 1: t, column 2: phi, column 3: d(phi)/dt; column 4: theta, column 5: d(theta)/dt
phi=output(:,2);   theta=output(:,4);

close all  % closing (i.e., deleting) all existing figures
figure('color', 'white'); plot(t, phi*180/pi);   grid    % plot of phi versus tau 
xlabel(['Nondimensional time', '  \tau'], 'fontsize', 12) 
ylabel(['\phi', ' (degrees)'], 'fontsize', 12),  title('Example 5.3.13','fontsize', 12)

figure('color', 'white');    plot(t, theta*180/pi);   grid        % plot of theta versus tau 
xlabel(['Nondimensional time', '  \tau'], 'fontsize', 12) 
ylabel(['\theta', ' (degrees)'], 'fontsize', 12),  title('Example 5.3.13','fontsize', 12)

% ANIMATION (distances are normalized by L):
len=length(t);  % this is the number of time occurrences in the given row matrix t  
col_of_zeros=zeros(len,1);   % this is a len by 1 column matrix of zeros
sin_phi=sin(phi); cos_phi=cos(phi);  sin_theta=sin(theta); cos_theta=cos(theta);    
xO=col_of_zeros; yO=xO;      xC2=sin_phi;  yC2=-cos_phi; 
xN=xC2+0.25*sin_theta;  yN= yC2+0.25*cos_theta;    
xM=xC2-0.25*sin_theta;  yM= yC2-0.25*cos_theta;  
x_coordinates=[xO, xC2, xN, xM];   y_coordinates=[yO, yC2, yN, yM]; 
animate_nbars(x_coordinates, y_coordinates)

function dy_dt=rhs_of_diff_eqs(t, y,  k_factor, c1_star, c2_star) 
    % Note:  y(1)=phi, y(2)=d(phi)/dt, y(3)=theta, y(4)=d(theta)/dt  
    dy_dt(1)=y(2);    % this is d(phi)/dt, and the next one is is d2(phi)/dt2 from Eq. (5.3.13j)    
    dy_dt(2)= -sin(y(1))-c1_star*y(2)-c2_star*(y(2)+y(4));
    dy_dt(3)=y(4);
    dy_dt(4)= -k_factor*c2_star*(y(2)+y(4));  % this mis from Eq. (5.3.13k)
    dy_dt=[dy_dt(1); dy_dt(2); dy_dt(3); dy_dt(4)];

% end of the file sim_model_ex5_3_13.m