function output=spring_pendulum(t, mg_over_kre, rs_0, dotrs_0, theta_0, dottheta_0)
% Animation of the spring-pendulum analyzed in Example 2.7.8  
% Example of usage ( using the initial conditions  rs_0=0.1; rsdot_0=0; theta_0=0.01; thetadot_0=0 ):
% my_output = spring_pendulum([0:0.02:350], 0.5^2, 0.1, 0, 0.01, 0);

disp(' ')
disp('NOTE: IN ADDITION TO ANIMATING THE SPRING-PENDULUM ANALYZED IN EXAMPLE 2.7.8,')
disp('AND PLOTTING theta and rs versus time, A CALL TO THE FUNCTION spring_pendulum ') 
disp('SUCH AS my_output = spring_pendulum([0:0.02:350], 0.5^2,  0.1, 0,  0.01, 0) )') 
disp('RETURNS 5 COLUMNS CONTAINING  t, rs,  d(rs)/dt, theta, and d(theta)/dt')
disp('TO PLOT d(rs)/dt, FOR EXAMPLE, VERSUS time, TYPE, IN THE MATLAB COMMAND WINDOW,');
disp('THE COMMANDS:    figure( );  plot(my_output(:,1), my_output(:,3)) ')
disp('   TO PUT A GRID ON THE PLOT, IF DESIRED, THEN TYPE  grid')

close all   % closing (i.e., deleting) all existing figures
len=length(t);   % this is the number of points in the array t  

initial_conditions=[rs_0; dotrs_0; theta_0; dottheta_0];
[t, y]=ode45(@rhs_of_diff_eqs, t, initial_conditions, [], mg_over_kre);
figure('color', 'white');   plot(t, y(:,3)); grid        % plot of theta versus time t
xlabel(['Nondimensional time  ', '\tau'], 'fontsize', 12);   ylabel('\theta', 'fontsize', 12);

figure('color', 'white');   plot(t, y(:,1));   grid;      % plot of rs versus t
xlabel(['Nondimensional time  ', '\tau'], 'fontsize', 12);   ylabel('r_s', 'fontsize', 12);

output=[t, y];  
% The variable output is a n by 5 matrix, where n is the number of points in the array t
% column 1: time, column 2: rs, column 3: d(rs)/dt; column 4: theta; column 5: d(theta)/dt

% ANIMATION: using a bar AB from the point (0,0) to (1+rs)*(sin_theta, -cos_theta)
rs=output(:,2);  theta=output(:,4);   % these are len by 1 columns
xO=zeros(len,1);  yO=xO;   xP=(1+rs).*sin(theta);  yP=-(1+rs).*cos(theta);    
x_coordinates=[xO, xP];  y_coordinates=[yO, yP];  animate_nbars(x_coordinates, y_coordinates);  

function dy_dt = rhs_of_diff_eqs(t, y, mg_over_kre) 
 % Note:  y(1)=rs, y(2)=d(rs)/dt, y(3)=theta, y(4)=d(theta)/dt
 dy_dt=[y(2); (1+y(1))*y(4)^2-mg_over_kre*(1-cos( y(3)) )-y(1); y(4); -(2*y(2)*y(4)+mg_over_kre*sin(y(3)) )/(1+y(1))]; 
% end of the file spring_pendulum.m

