function output = top_dynamics(t, Iz_over_In, mgL_over_In, phidot_0, psidot_0, theta_0, thetadot_0)
% Top dynamics analyzed in Section 6.6.3
% Example of usage ( using the initial conditions  
%               phidot_0=5.03; psidot_0=45.65; theta_0=pi/6; thetadot_0=0 ): 
% my_output = top_dynamics([0:0.001:10], 27/68, 27*98.1/34, 5.03, 45.65, 30*pi/180, 0);

disp(' ')
disp('NOTE: IN ADDITION TO ANIMATING THE MOTION OF THE TOP, A CALL SUCH AS ')
disp(' output = top_dynamics([0:0.001:10], 27/68, 27*98.1/34, 5.03, 45.65, 30*pi/180, 0);') 
disp('RETURNS, IN THE VARIABLE output, 4 COLUMNS CONTAINING  t, phi, theta, dtheta_dt')
disp(' ')

phi_0=0;  
[t, y]=ode45(@rhs_of_diff_eqs, t, [phi_0; theta_0; thetadot_0], [], Iz_over_In, mgL_over_In, phidot_0, psidot_0, theta_0, thetadot_0);   
output=[t, y];   
% The variable output is a n by 4 matrix, where n is the number of points in the array t
% 1st column: t,  2nd column: phi, 3rd column: theta; 4th column: d(theta)/dt

phi=output(:,2); theta=output(:,3);   sin_theta=sin(theta);  cos_theta=cos(theta);  
sin_phi=sin(phi);  cos_phi=cos(phi);

close all  % deleting all existing figures
% Plot of phi versus time
figure('color', 'white');  plot(t, phi*180/pi),   grid        % plot of phi versus time t
xlabel('t  (seconds)', 'fontsize', 12), ylabel(['\phi  ', '(degrees)'], 'fontsize', 12) 
title('Top dynamics','fontsize', 12) 

% Plot of theta versus time
figure('color', 'white');  plot(t, theta*180/pi),   grid        % plot of theta versus t
xlabel('t  (seconds)', 'fontsize', 12),   ylabel(['\theta  ', '(degrees)'], 'fontsize', 12)

% ANIMATION:  
len=length(t);   % number of points in the given array t 
xO=zeros(len,1); yO=xO; zO=xO;   % these are columns oz zeros
xC=sin_theta.*cos_phi;  yC=sin_theta.*sin_phi;  zC=cos_theta;
x_coordinates=[xO, xC];  y_coordinates=[yO, yC];  z_coordinates=[zO, zC];  
animate3d_nbars(x_coordinates, y_coordinates, z_coordinates)

function dy_dt=rhs_of_diff_eqs(t, y,  Iz_over_In, mgL_over_In, phidot_0, psidot_0, theta_0, thetadot_0) 
% y(1)=phi, y(2)=theta, y(3)=d(theta)/dt, 
    cos_theta0=cos(theta_0);    sin_theta0=sin(theta_0);  sin_theta=sin(y(2));  cos_theta=cos(y(2));
    omegaz = psidot_0+phidot_0*cos_theta0 ;  
    Hz0_over_In = phidot_0*(sin_theta0^2)+Iz_over_In*omegaz*cos_theta0;
    dy_dt(1)= (Hz0_over_In - Iz_over_In*omegaz*cos_theta)/(sin_theta^2);      % this is d(phi)/dt
    dy_dt(2)=y(3);    % this is d(theta)/dt     
    dy_dt(3)= ( mgL_over_In + (dy_dt(1)*cos_theta - Iz_over_In*omegaz)*dy_dt(1) )*sin_theta;    
      % the above is d2(theta)/dt2
    dy_dt=[dy_dt(1); dy_dt(2); dy_dt(3)];

% end of the file top_dynamics.m
