function output=two_particles_table(t, m2_over_m2plusm1, g_over_L, r_0, rdot_0, theta_0, thetadot_0)
% Animation of Example 2.7.10. Here, the distance denoted by r is actually r/L
% State variables: y(1)=r_over_L, y(2)=d(r_over_L)/dt, y(3)=theta, y(4)=d(theta)/dt
% Example of usage  ( using the initial conditions  for the state variables: [0.5; 0;  0; 2] ):
% my_output = two_particles_table([0:0.001:10], 0.5, 9.81, 0.5, 0,  0, 2);

disp(' ')
disp(' NOTE: IN ADDITION TO ANIMATING THE SYSTEM IN EXAMPLE 2.7.10, A CALL TO THE ')
disp(' FUNCTION two_particles_table (SUCH AS ') 
disp(' my_output = two_particles_table([0:0.001:10], 0.5, 9.81, [0.5; 0; 0; 2]) )') 
disp(' RETURNS 5 COLUMNS CONTAINING t, r_over_L,  d(r_over_L)/dt, theta, and d(theta)/dt')
disp(' TO PLOT r_over_L, FOR EXAMPLE, VERSUS time, USE THE COMMANDS ');
disp('       figure( ); plot(my_output(:,1), my_output(:,2)) ')
disp('TO PUT A GRID ON THE PLOT, IF DESIRED, THEN TYPE   grid')
disp(' ')

initial_conditions=[r_0; rdot_0; theta_0; thetadot_0];
[t, y]=ode45(@rhs_of_diff_eqs, t, initial_conditions, [],  m2_over_m2plusm1, g_over_L);   
output=[t, y];  
% the variable output is a len by 5 matrix, where len is the number of points in the array t
% column 1: t, column 2: r/L, column 3: d(r/L)/dt; column 4: theta; column 5: d(theta)/dt

% ANIMATION: We have two bars, O_P1 and O_P2, and the total normalized length 
% of the system of bars is r/L+(L-r)/L=1
len=length(t);
r=output(:,2); theta=output(:,4); sin_theta=sin(theta); cos_theta=cos(theta); 
x_O=zeros(len,1); y_O=x_O; z_O=x_O;   x_P1=r.*cos_theta;   y_P1=r.*sin_theta;  z_P1=x_O;  % bar O_P1
x_P2=x_O;  y_P2=x_O;  z_P2=r-1;      % end P2 of bar O_P2
x_coordinates=[x_P2, x_O, x_P1];  y_coordinates=[y_P2, y_O, y_P1];  z_coordinates=[z_P2, z_O, z_P1]; 
animate3d_nbars(x_coordinates, y_coordinates, z_coordinates);

function dy_dt=rhs_of_diff_eqs(t, y,  m2_over_m2plusm1, g_over_L) 
    % Note:  y(1)=r_over_L, y(2)=d(r_over_L)/dt, y(3)=theta, y(4)=d(theta)/dt
  dy_dt(1)=y(2);   % the next expression is d2(r_over_L)/dt2 from Eq. (2.7.10l)
  dy_dt(2)=(1-m2_over_m2plusm1)*y(1)*y(4)^2 -m2_over_m2plusm1*g_over_L; 
  dy_dt(3)=y(4);  
  dy_dt(4)=-2*y(2)*y(4)/y(1);   % this is d2(theta)/dt2 obtained from Eq. (2.7.10k)
  dy_dt=[dy_dt(1); dy_dt(2); dy_dt(3); dy_dt(4)];

% end of the file two_particles_table.m
