function animate3d_nbars(x_coordinates, y_coordinates, z_coordinates)
//        3D animation of any number of connected bars
// When given the lists x_coordinates=[xA, xB, xC, etc], y_coordinates(yA, yB, yC, etc) 
// and z_coordinates(zA, zB, yzC, etc) of the  
// x-y-z coordinates of several points A, B, C, etc, a call to the function animate3d_nbars.sci
// generates a set of straight lines by connecting the points in the  given sequence A, B, C, etc, 
// with a black dot at each point. Thus a call such as animate3d_nbars([xA, xB, xC], [yA, yB, yC]), 
// [zA, zB, zC]), typed in the SCILAB console, creates a figure window with two lines AB and BC, 
// with black dots at the ends of each line. When xA, xB, xC, etc; yA, yB, yC, etc; and zA, zB, zC, 
// etc, are n by m arays, an animation is displayed.     
// This function is called by top_dynamics.sci and two_particles_table.sci
// to animate the 3D motion. See those programs and run them to watch the motion.

// *****************************************************************************************
// NOTE: Comment out this part if you don't want to see this message after you get used to it
disp(' '); disp('  =====>  IMPORTANT MESSAGE:  <=====')
disp(' IF THE SIMULATION RUNS EITHER TOO FAST OR TOO SLOW IN YOUR COMPUTER,')
disp(' change the time_step in the time array t=[t0:time_step:tfinal] of your simulation ')
disp(' ---> EITHER to a smaller value to slow down the animation ')
disp(' ---> OR to a larger value to speed up the animation')
// *****************************************************************************************

[number_of_time_points, len]=size(x_coordinates); 
// minimum and maximum value of x_coordinates, y_coordinates, and z_coordinates:
xcoord_min=min(x_coordinates); xcoord_max=max(x_coordinates);   
ycoord_min=min(y_coordinates); ycoord_max=max(y_coordinates);   
zcoord_min=min(z_coordinates); zcoord_max=max(z_coordinates);   

// Create a figure window for the animation. Start by determining the computer monitor size
// so that the animation window is properly placed and sized in any computer screen. 
screen_width_and_height=get(0,'screensize_px')  // width and height of the screen, in pixels
PC_screen_width =screen_width_and_height(3)     // this is the width of the computer monitor
PC_screen_height=screen_width_and_height(4)     // this is the height of the computer monitor

x_topleft= 0.65*PC_screen_width  // choice for the top left x-coordinate of the figure window
y_topleft= 0.3*PC_screen_height  // choice for the top left y-coordinate of the figure window
top_left_coordinates=[x_topleft, y_topleft] 
size_of_fig_window = [0.32*PC_screen_width, 0.47*PC_screen_height]  
// the above are the width and height chosen for the animation window
// Now, create the figure window.  NOTE: 'background', 8   is for a white background)
fig=figure(300, 'figure_position',top_left_coordinates,'figure_size', size_of_fig_window, 'figure_name','Animation window', 'background', 8);  xgrid

fig.children.isoview='on';  col_of_zeros=zeros(len,1);  
param3d(col_of_zeros, col_of_zeros, col_of_zeros); // this initializes the plot
     // NOTE: Sicilab's plot3d draws a filled surface, instead of lines in 3D
     //       To draw lines in 3D, the Scilab command to use is param3d
h_gce = gce();    // h_gce.data  is the data that will be plotted
h_gce.mark_mode="on";    h_gce.mark_size=1; 
// NOTE: Put a // at the beginning of the line, above, if no dots are desired

h_axes = gca();   // need this to set the axes limits, the rotation_angles for viewing the fig, etc
h_axes.data_bounds = [xcoord_min, ycoord_min, zcoord_min; xcoord_max, ycoord_max, zcoord_max];
h_axes.rotation_angles=[60,-120];  // comment this out if the default rotation_angles is desired
// NOTE: Comment out the above line if the default rotation_angles is desired

 for itime=1:number_of_time_points      // this is the animation loop
   temp=[ ];
   for k=1:len
     temp=[temp; x_coordinates(itime,k), y_coordinates(itime,k), z_coordinates(itime,k)]; 
   end  
   drawlater();
     h_gce.data=temp; 
   drawnow();
 end 
endfunction      // end of the file animate3d_nbars.sci

