function animate_nbars(x_coordinates, y_coordinates)
//        2D animation of any number of connected bars
// When given the lists x_coordinates=[xA, xB, xC, etc] and y_coordinates(yA, yB, yC, etc) of the  
// x and y coordinates of several points A, B, C, etc, a call to the function animate_nbars.sci
// generates a set of straight lines by connecting the points in the  given sequence A, B, C, etc, 
// with a black dot at each point. Thus a call such as animate_nbars([xA, xB, xC], [yA, yB, yC]), 
// typed in the SCILAB console, creates a figure window with two lines AB and BC, with black dots 
// at the ends of each line. When xA, xB, xC, etc, and yA, yB, yC, etc, are n by m matrices, an  
// animation is created displaying the lines whose end point coordinates are specified in each  
// row of the matrix.  This function is called by several others of the type .sci (such as 
// ballistics.sci, boomerang.sci, fourbar_mechanism.sci, etc). For information on the animation  
// of the four bar mechanism, for example, type     head_comments fourbar_mechanism 

// NOTE: For complete information on Graphics and Graphical User Interfaces in general (for   
//  Scilab, Matlab, etc), those who are interested may want to look at (especially Chs. 3 and 5) 
//       Marchand, Patrick, (1966). Graphics and GUIs with MATLAB. CRC Press

// *****************************************************************************************
// NOTE: Comment out this part if you don't want to see this message after you get used to it
disp(' '); disp('  =====>  IMPORTANT MESSAGE:  <=====')
disp(' IF THE SIMULATION RUNS EITHER TOO FAST OR TOO SLOW IN YOUR COMPUTER,')
disp(' change the time_step in the time array t=[t0:time_step:tfinal] of your simulation ')
disp(' ---> EITHER to a smaller value to slow down the animation ')
disp(' ---> OR to a larger value to speed up the animation')
// *****************************************************************************************
 
[number_of_time_points, len]=size(x_coordinates);  // size gives the dimensions of a matrix

// minimum and maximum values of x_coordinates and y_coordinates: 
xcoord_min=min(x_coordinates);  xcoord_max=max(x_coordinates);   
ycoord_min=min(y_coordinates);  ycoord_max=max(y_coordinates); 

// Create a figure window for the animation. Start by determining the computer monitor size
// so that the animation window is properly placed and sized in any computer screen. 
screen_width_and_height=get(0,'screensize_px')   // width and height of the screen, in pixels
PC_screen_width =screen_width_and_height(3)     // this is the width of the computer monitor
PC_screen_height=screen_width_and_height(4)     // this is the height of the computer monitor

x_topleft= 0.65*PC_screen_width  // choice for the top left x-coordinate of the figure window
y_topleft= 0.3*PC_screen_height  // choice for the top left y-coordinate of the figure window
top_left_coordinates=[x_topleft, y_topleft] 
size_of_fig_window = [0.32*PC_screen_width, 0.47*PC_screen_height]  
// the above are the width and height chosen for the animation window
// Now, create the figure window.  NOTE: 'background', 8   is for a white background)
fig=figure(300, 'figure_position',top_left_coordinates,'figure_size', size_of_fig_window, 'figure_name','Animation window', 'background', 8)

// The variable fig is a "handle" (so called in analogy with the handles of a cabinet, say)
// of type "Figure", that has several properties that can be modified by the user (to see those  
// properties, type the above command in the Scilab console; you will see that one of the 
// properties is named children, which is also a handle with its own properties, as any handle). 
// The command  h_gce=gce()   (for "get current entity"), or  h_gce=fig.children typed after 
// creating a figure, shows the properties of the handle of type "Axes" of the figure window that 
// is  displayed on the computer screen. Three of such properties are named isoview, 
// mark_mode, and mark_size. The isoview property is set to off by default. If it is left as off, 
// a circle, if plotted, will show on the computer screen as an ellipse. To force it to appear as a 
// circle, isoview needs to be set to  on  (enclosed in quotes).  
// The commands that will do this are the following:

h_gce=gce()
h_gce.isoview='on'    // we could have used, instead,  fig.children.isoview='on'

// Now, initialize (say, with the initial position of all the bars) the 2D plot with a call to plot.
// This will modify the "current entity" to account for the creation of the lines by the plot
// command. 
plot(x_coordinates(1,:), y_coordinates(1,:)) 
    // The first row array is [xA1, xB1, xC1, etc], and the second is [yA1, yB1, yC1, etc] 
 
// If you now type gce(), it will be seen that the new entity (the lines the plot command created) is
// a handle ot type "Compound" for which two of its properties are  parent: Axes,  Children: Polyline
// We need to "get the current entity" [the command for this is gce( )] in order to modify some of its 
// properties that are needed for an animation. Reusing the same variable name h_gce, we can do this 
// with the following command:

h_gce=gce( )    // we could have used, instead, h_gce=fig.children.children
  
// Now, access the handle h_gce.children, which has a property named data that stores the x and 
// y coordfinates of the ends of the lines that were created (i.e., such data is stored in  
// h_gce.children.data) as a 2-column matrix. For an animation, this, then, will be put in a loop  
// so that all the lines AB, BC, etc, are plotted in sequence. Before we start that loop, we will
// put a dot (by choice) at the end of each bar. This is done with the following two commands to 
// change the settings of two other properties of h_gce.children named mark_mode and mark_size. 
// The first command makes it possible to add the dots, and the second command is for specifying 
// a size for the dot [if you do not want such markings, comment out the following two command 
// lines by putting a double slash (//) at the beginning of their lines]. 

h_gce.children.mark_mode='on';   // set to on so that we can put a dot at the ends of the bars
h_gce.children.mark_size=10;     // this is the size we chose for the black dot   

// The final steps now consist in telling the software to "get the current axes" (which are the x   
// and y axes that were created by the plot command) and limiting them to the maximum and minimun 
// values xcoord_min, xcoord_max, ycoord_min, and ycoord_max obtained earlier. The software stores 
// such values in the property named  data_bounds   of the current axes. Such axes are accessed  
// with the command gca ( ).  

h_axes = gca();      // gca stands for "get current axes"; this accesses the current axes
h_axes.data_bounds = [xcoord_min, ycoord_min; xcoord_max, ycoord_max] // the axes limits
 
// Now, the loop that will generate the animation after changing h_gce.children.data at each step.
// NOTE: there is a transpose operation in the loop because h_gce.children.data stores the data  
//       specified in the command plot([xA, xB, xC], [yA, yB, yC]), for example, in a 3 by 2 matrix  
//       as [xA, yA; xB, yB; xC, yC], which is the same as [ [xA, xB, xC]', [yA, yB, yC]' ] 
//       (i.e., h_gce.children.data needs to be a 2-column matrix)

  for itime=1:number_of_time_points  
    drawlater();        
    h_gce.children.data = [x_coordinates(itime,:)', y_coordinates(itime,:)']; 
    drawnow(); // type  help drawnow for information on the the pair drawlater drawnow
  end 
endfunction      // end of the file  animate_nbars.sci

 


