function output = boomerang(t, g, x_0, dotx_0, y_0)
// Example 7.9.1; using the state variables var(1)=x, var2=dx/dt, var(3)=y
// Example of usage [ using the initial conditions x(0)=0, dx_dt(0)=5*cos(pi/6), y(0)=0 ] 
// my_output =  boomerang([0:0.01:6], 9.81, 0, 5*cos(%pi/6), 0);

function dvar_dt=rhs_of_diff_eqs(t, var) 
    // Note:  var(1)=x, var(2)=d(x)/dt, var(3)=y;  The diff. eqs. are Eqs. (7.9.1j) and (7.9.1i)
         f1=0.5*sin(t);  df1_dt=0.5*cos(t);    f2=5*sin(%pi/6)-0.85*t; df2_dt=-0.85;
    dvar_dt(1)=var(2),    // this is d(theta)/dt     
    dvar_dt(2)=-(var(2)*df1_dt+df2_dt+g)*f1/(1+f1^2) // this is Eq. (7.9.1j)   
    dvar_dt(3)= f1*var(2)+f2       // this is Eq. (7.9.1i)
endfunction

initial_conditions=[x_0; dotx_0; y_0];
state_variables=ode(initial_conditions, 0, t, rhs_of_diff_eqs),   
output=[t', state_variables']   // ' is the transpose operator
    // this is a n by 4 matrix, where len is the number of points in the array t
    // column 1: t, column 2: x, column 3: dx/dt; column 4: y  

x=output(:,2), y=output(:,4)

xdel(winsid())  // deleting all existing figures
figure('background', 8)    //  'background' 8 forces the figure background to be white
plot(t', x,  t', y, '--'),   xgrid        // plot of x and y versus time t
xlabel('t', 'fontsize', 3), ylabel('solid line: x   ;   dashed line: y', 'fontsize', 3), 
title('Example 7.9.1','fontsize', 3)

figure('background', 8);    plot(x, y);   xgrid        // plot of y versus x
xlabel('x', 'fontsize', 3), ylabel('y', 'fontsize', 3), title('Example 7.9.1','fontsize',3)
  
animate_nbars(x, y);    // This call animates the motion 
endfunction      // end of the file  boomerang.sci
