function output=parabola_track(t, a, k_over_m, c_over_m, Lu, h, g, x_0, xdot_0)
// Example 2.8.9 
// Example of usage (with the initial conditions   x(0)=-1,5; xdot(0)=3*sqrt(2))):
// my_output = parabola_track([0:0.005:3], 1/3, 9/0.02, 1.4, 1.2, 1.2, 9.81,  -1.5, 3*sqrt(2));
// NOTE:  my_output is a matrix. The first column is the transpose of t, the second column is
//       x(t) for the time instants defined in the array t, and the third column is dx/dt

function dy_dt=rhs_of_diff_eqs(t, y) 
  // Note:  y(1)=x, y(2)=dx/dt
  x_squared=y(1)^2
  dy_dt(1)=y(2)     // the next expression is d2x_dt2 from Eq. (2.8.9c) 
  dy_dt(2)=(k_over_m*(1-Lu/sqrt(y(1)^2+(a*y(1)^2-h)^2))*(2*a*(h-a*y(1)^2)-1)*y(1) ...
            -2*a*g*y(1)-4*a^2*y(1)*y(2)^2)/(1+4*(a^2)*y(1)^2)-c_over_m*y(2)
endfunction

initial_conditions=[x_0; xdot_0]
state_variables=ode(initial_conditions, 0, t, rhs_of_diff_eqs) 
output=[t', state_variables']  
// The variable output is a n by 3 matrix, where n is the number of points in the array t
// column 1: t;  column 2: x;  column 3: dx/dt  

xdel(winsid())  // deleting all existing figures
// Create a figure window and plot x(t) versus time t
figure('background', 8);  plot(t, state_variables(1,:)),   xgrid 
xlabel('t  (seconds)', 'fontsize', 3), ylabel('x(t)  (meters)', 'fontsize', 3) 
title('Example 2.8.8','fontsize', 3)

// ANIMATION of the ball moving on the parabolic track y=a*x^2
  x=output(:,2),  y=a*x.^2,  animate_nbars(x, y)       
endfunction      // end of the file  parabola_track.sci
