function output = pend_moving_base(t, g_over_L, c_over_mLsquare,  theta_0, thetadot_0)
// Example 2.7.6;  Use item_number=2 for Part c, and item_number=1 for Part d in that example
//    NOTE:  if desired, change the expressions for aA_over_L 
// Example of usage ( using the initial conditions  theta_0=0; thetadot_0=0 ):  
// my_output = pend_moving_base([0:0.005:15], 9.81, 1,   0, 0);
        
disp('  Enter the item number for Example 2.7.6 in Chapter 2')
disp('  USE 2 for item c, 1 for item d')
item_number=input(' ')        
if  item_number==2 then message='Part c', elseif item_number==1 then message='Part d',  end

if item_number ~=1 & item_number ~=2 then       // ~= means  not equal; & means and
  disp('item_number MUST BE EITHER 1 OR 2') 
  disp('use item_number=2 to do Part c of Example 2.7.6, and 1 to do Part d')
  output=[], return
end

function dy_dt=rhs_of_diff_eqs(t, y) 
   // Note:  y(1)=theta, y(2)=d(theta)/dt
 if item_number==2  then aA_over_L=2*9.81   // the constant aceleration input for Part c
   elseif item_number==1 then
   aA_over_L=5*t; if t>=5 then aA_over_L=0, end  // the ramp acceleration input for Part d
 end 
dy_dt(1)=y(2)    // this is d(theta)/dt and the next line is d2(theta)/dt2      
dy_dt(2)=-g_over_L*sin(y(1)) + aA_over_L*cos(y(1)) - c_over_mLsquare*y(2)  
endfunction

initial_conditions=[theta_0; thetadot_0]
state_variables=ode(initial_conditions, 0, t, rhs_of_diff_eqs) 
output=[t', state_variables']  
// The variable output is a n by 3 matrix, where n is the number of points in the array t
// column 1: t, column 2: theta, column3: d(theta)/dt  

xdel(winsid())  // deleting all existing figures
fig=figure('background', 8)    //  'background' 8 forces the figure background to be white 
plot(t', output(:,2)*180/%pi),   xgrid        // plot of theta versus time t
xlabel('t  (seconds)', 'fontsize', 3), ylabel(['$\theta$', ' (degrees)'], 'fontsize', 3) 
title('Example 2.7.6','fontsize', 3)
uicontrol(fig,'style','text', 'position',[10,10,70,30],  'string', message, 'fontsize', 18)   
 // type    help uicontrol    in the Scilab console for a description of the command uicontrol 

// ANIMATION: using a simple model consisting of a bar AB, with A(0,0) and B(sin_theta, -cos_theta) 
//            (lenghts are normalized by L)
  len=length(t),   theta=output(:,2)       // theta is a len by 1 column
  xA=zeros(len,1), yA=xA,   xB=sin(theta), yB=-cos(theta)  // these are len by 1 columns
  x_coordinates=[xA, xB];   y_coordinates=[yA, yB]  
  animate_nbars(x_coordinates, y_coordinates)    // this creates the animation
endfunction      // end of the file pend_moving_base.sci
