function output=spring_pendulum(t, mg_over_kre, rs_0, dotrs_0, theta_0, dottheta_0)
// Animation of the spring-pendulum analyzed in Example 2.7.8  
// Example of usage [with the initial conditions 
//              rs(0)=0.1; rsdot(0)=0; theta(0)=0.01; thetadot(0)=0]:
// my_output = spring_pendulum([0:0.1:350], 0.5^2,  0.1, 0,  0.01, 0);

disp('NOTE: IN ADDITION TO ANIMATING THE SPRING-PENDULUM ANALYZED IN EXAMPLE 2.7.8,')
disp('AND PLOTTING theta and rs versus time, A CALL TO THE FUNCTION spring_pendulum')  
disp(' (SUCH AS my_output = spring_pendulum([0:1:350], 0.5^2,  0.1, 0,  0.01, 0)') 
disp('RETURNS 5 COLUMNS CONTAINING  t, rs,  d(rs)/dt, theta, and d(theta)/dt')
disp('TO PLOT d(rs)/dt, FOR EXAMPLE, VERSUS time, TYPE, IN THE SCILAB CONSOLE:')
disp('       figure(); plot(my_output(:,1), my_output(:,3)) ')
disp('OR:  figure( ); plot2d(my_output(:,1), my_output(:,3));')
disp('   To put a grid on the plot, type  xgrid ')

function dy_dt=rhs_of_diff_eqs(t, y) 
    // Note:  y(1)=rs, y(2)=d(rs)/dt, y(3)=theta, y(4)=d(theta)/dt
  dy_dt(1)=y(2)   
  dy_dt(2)=(1+y(1))*y(4)^2-mg_over_kre*(1-cos( y(3) ) )-y(1)  // this is d2(rs)/dt2
  dy_dt(3)=y(4)
  dy_dt(4)=-(2*y(2)*y(4)+mg_over_kre*sin( y(3) ) )/(1+y(1))  // this is d2(theta)/dt2
endfunction

initial_conditions=[rs_0; dotrs_0; theta_0; dottheta_0]; 
y=ode(initial_conditions, 0, t, rhs_of_diff_eqs) 
// pause    // NOTE: this pause command is here only to explain, in Appendix A, what it does

xdel(winsid())  // deleting all existing figures
figure('background', 8)    //  'background' 8 forces the figure background to be white
plot(t, y(3,:)),   xgrid   // plot of theta versus time t
xlabel(['Nondimensional time', '$\tau$'], 'fontsize', 3), ylabel('$\theta$', 'fontsize',4)

figure('background', 8), plot(t, y(1,:)),   xgrid      // plot of rs versus t
xlabel(['Nondimensional time', '$\tau$'], 'fontsize', 3),  ylabel('$r_s$', 'fontsize', 5)

output=[t', y']   
// The variable output is a n by 5 matrix, where n is the number of points in the array t
 // column 1: t, column 2: rs, column 3: d(rs)/dt; column 4: theta; column 5: d(theta)/dt

// ANIMATION: using a bar AB from the point (0,0) to (1+rs)*(sin_theta, -cos_theta)
 len=length(t),   // this is the number of points in the array t
 rs=output(:,2), theta=output(:,4)      // these are len by 1 columns
 xA=zeros(len,1), yA=xA,   xB=(1+rs).*sin(theta), yB=-(1+rs).*cos(theta)    // bar AB
 x_coordinates=[xA, xB], y_coordinates=[yA, yB], animate_nbars(x_coordinates, y_coordinates)  
endfunction      // end of the file spring_pendulum.sci
